==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_filemanager.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_filemanager.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("FMLAN_1", "Uploaded");
define("FMLAN_2", "to");
define("FMLAN_3", "directory");
define("FMLAN_4", "The uploaded file exceeds the upload_max_filesize directive in php.ini.");
// define("FMLAN_5", "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the html form.");
// define("FMLAN_6", "The uploaded file was only partially uploaded.");
// define("FMLAN_7", "No file was uploaded.");
// define("FMLAN_8", "Uploaded file size 0 bytes");
// define("FMLAN_9", "The file did not upload. Filename");
// define("FMLAN_10", "Error");
// define("FMLAN_11", "Probably incorrect permissions on upload directory.");
define("FMLAN_12", "file");
define("FMLAN_13", "files");
define("FMLAN_14", "directory");
define("FMLAN_15", "directories");
define("FMLAN_16", "Root directory");
define("FMLAN_17", "Name");
define("FMLAN_18", "Size");
define("FMLAN_19", "Last Modified");

define("FMLAN_21", "Upload file to this dir");
define("FMLAN_22", "Upload");

define("FMLAN_26", "Deleted");
define("FMLAN_27", "successfully");
define("FMLAN_28", "Unable to delete");
define("FMLAN_29", "Path");
define("FMLAN_30", "Up level");
define("FMLAN_31", "folder");

define("FMLAN_32", "Select Directory");
define("FMLAN_33", "Select");
define("FMLAN_34", "Directory Choice");
define("FMLAN_35", "Files Directory");

define("FMLAN_36", "Custom Menus Directory");
define("FMLAN_37", "Custom Pages Directory");

define("FMLAN_38", "Successfully moved file to");
define("FMLAN_39", "Unable to move file to");
define("FMLAN_40", "Newspost-Images Directory");


define("FMLAN_43", "Delete selected files");


define("FMLAN_46", "Please confirm that you wish to DELETE the selected files.");
define("FMLAN_47", "User Uploads");

define("FMLAN_48", "Move selected to");
define("FMLAN_49", "Please confirm you wish to move the selected files.");
define("FMLAN_50", "Move");



?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/admin/lan_filemanager.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_filemanager.php $
|     $Revision: 11790 $
|     $Id: lan_filemanager.php 11790 2010-09-16 20:02:09Z e107steved $
|     $Author: e107steved $
+----------------------------------------------------------------------------+
*/
define("FMLAN_1", "Uploaded");
define("FMLAN_2", "to");
define("FMLAN_3", "directory");
define("FMLAN_4", "The uploaded file exceeds the upload_max_filesize directive in php.ini.");
// define("FMLAN_5", "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the html form.");
// define("FMLAN_6", "The uploaded file was only partially uploaded.");
// define("FMLAN_7", "No file was uploaded.");
// define("FMLAN_8", "Uploaded file size 0 bytes");
// define("FMLAN_9", "The file did not upload. Filename");
define('FMLAN_10', 'Error');
// define("FMLAN_11", "Probably incorrect permissions on upload directory.");
define("FMLAN_12", "file");
define("FMLAN_13", "files");
define("FMLAN_14", "directory");
define("FMLAN_15", "directories");
define("FMLAN_16", "Root directory");
define("FMLAN_17", "Name");
define("FMLAN_18", "Size");
define("FMLAN_19", "Last Modified");

define("FMLAN_21", "Upload file to this dir");
define("FMLAN_22", "Upload");

define("FMLAN_26", "Deleted");
define("FMLAN_27", "successfully");
define("FMLAN_28", "Unable to delete");
define("FMLAN_29", "Path");
define("FMLAN_30", "Up level");
define("FMLAN_31", "folder");

define("FMLAN_32", "Select Directory");
define("FMLAN_33", "Select");
define("FMLAN_34", "Directory Choice");
define("FMLAN_35", "Files Directory");

define("FMLAN_36", "Custom Menus Directory");
define("FMLAN_37", "Custom Pages Directory");

define("FMLAN_38", "Successfully moved file to");
define("FMLAN_39", "Unable to move file to");
define("FMLAN_40", "Newspost-Images Directory");


define("FMLAN_43", "Delete selected files");


define("FMLAN_46", "Please confirm that you wish to DELETE the selected files.");
define("FMLAN_47", "User Uploads");

define("FMLAN_48", "Move selected to");
define("FMLAN_49", "Please confirm you wish to move the selected files.");
define("FMLAN_50", "Move");
define('FMLAN_51', 'Unidentified error: ');




?>
